Crate grammarbot

grammarbot-rs

An API client for GrammarBot - a free grammar checking API.

Usage

A Client is the primary way to interact with the API.

use grammarbot::Client;
let client = Client::new("your_api_key");

Use check to check your texts.

let response = client.check("I can't remember how to go their.");

The Response struct stores all information in the fields that you can access directly:

assert_eq!("CONFUSION_RULE", response.matches[0].rule.id);

Modules

  • All the entities used in responses from the API.

Structs

  • The primary way to interact with the API.
  • A typed representation of the JSON response.

Enums

  • A domain-specific error type.

Type Aliases